@@ -27,8 +27,8 @@ as their content is relevant for command line use of the `refinery`.
 Furthermore, the module documentation of `refinery.units` contains a brief
 example of how to write simple units.
 """
-__version__ = '0.4.14'
-__pip_pkg__ = 'binary-refinery'
+__version__ = '0.4.15'
+__distribution__ = 'binary-refinery'
 
 from typing import Dict, Type
 
