@@ -48,9 +48,10 @@ class esc(Unit):
     def process(self, data):
         if self.args.quoted:
             quote = data[0]
-            if data[~0] != quote:
-                raise ValueError('string is not correctly quoted')
-            data = data[1:~0]
+            if data[-1] != quote:
+                self.log_info('string is not correctly quoted')
+            else:
+                data = data[1:-1]
 
         if self.args.unicode:
             return data.decode('UNICODE_ESCAPE').encode(self.codec)
@@ -75,7 +76,7 @@ class esc(Unit):
                 return c if self.args.greedy else match[0]
             return self._UNESCAPE.get(c, c)
         data = re.sub(
-            RB'\\(u[a-fA-F0-9]{4}|x[a-fA-F0-9]{2}|[0-7]{3}|.)', unescape, data)
+            RB'\\(u[a-fA-F0-9]{4}|x[a-fA-F0-9]{1,2}|[0-7]{3}|.)', unescape, data)
         return data
 
     def reverse(self, data):
